"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorCodes = exports.WARNING_NOTIFICATION = exports.SUCCESSFUL_NOTIFICATION = void 0;
const Constants_1 = require("./Constants");
exports.SUCCESSFUL_NOTIFICATION = {
    code: Constants_1.SUCCESSFUL_CODE,
    level: Constants_1.INFO_LEVEL,
    message: Constants_1.SUCCESSFUL_MESSAGE,
    timestamp: new Date()
};
exports.WARNING_NOTIFICATION = {
    code: Constants_1.WARNING_CODE,
    level: Constants_1.WARNING_LEVEL,
    message: '',
    timestamp: new Date()
};
exports.ErrorCodes = {
    GenericErrors: [
        {
            statusCode: 401,
            errorCode: 'EL4011001',
            errorSearch: 'user_auth_error',
            message: 'Cognito UserModel in Authorization Token is not present',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001001',
            errorSearch: 'missing_params_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4002007',
            errorSearch: 'generate_signed_url_failed',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4002008',
            errorSearch: 'store_file_failed',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4002009',
            errorSearch: 'get_file_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AuthSigninHandler: [
        {
            statusCode: 403,
            errorCode: 'EL4031001',
            errorSearch: 'Incorrect username or password.',
            message: 'The username or password provided is not correct.',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AuthPassResetHandler: [
        {
            statusCode: 403,
            errorCode: 'EL4031002',
            errorSearch: 'Incorrect username or password.',
            message: 'The username or password provided is not correct.',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AuthRefreshHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091015',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 403,
            errorCode: 'EL4031003',
            errorSearch: 'Invalid Refresh Token',
            message: 'Refresh Token is invalid.',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AuthPassForgetInitHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091016',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AuthPassForgetHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091017',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 401,
            errorCode: 'EL4011002',
            errorSearch: 'Invalid verification code provided, please try again.',
            message: 'Your provided code is not correct',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    UserHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091018',
            errorSearch: 'An account with the given email already exists.',
            message: 'An account with the provided email already exists.',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 401,
            errorCode: 'EL4011003',
            errorSearch: 'Password did not conform with policy: Password must have symbol characters',
            message: 'Your password must include symbol characters',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091019',
            errorSearch: 'Password did not conform with policy: Password not long enough',
            message: 'Your password must be 8 characters or longer',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091020',
            errorSearch: 'user_already_exists',
            message: 'A user with the given emil address already exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091024',
            errorSearch: 'phone_already_exists',
            message: 'An account with the given phone number already exists.',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    UserResendVerificationHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091025',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 401,
            errorCode: 'EL4011004',
            errorSearch: 'max_retries_exceeded',
            message: 'You have reached the max number of retries',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091026',
            errorSearch: 'phone_already_verified',
            message: 'This phone number has been already verified',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificUserHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091027',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    UserUpdateHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091028',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091029',
            errorSearch: 'user_number_update_error',
            message: 'New user phone cannot be the same as the previous one',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    LookupUserHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091030',
            errorSearch: 'email_not_present',
            message: 'An email address must be provided',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001002',
            errorSearch: 'email_validation_error',
            message: 'An email address must be provided',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    UserVerificationHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091031',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091032',
            errorSearch: 'invalid_code',
            message: 'Entered code is invalid',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091033',
            errorSearch: 'code_expired',
            message: 'Your code has expired',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091034',
            errorSearch: 'phone_already_verified',
            message: 'This phone number has been already verified',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    UploadSpecificVerificationHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091035',
            errorSearch: 'Verification_Not_Exist',
            message: 'Verification not exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091036',
            errorSearch: 'Document_Validated',
            message: 'Document already validated',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091037',
            errorSearch: 'Verification_Validated',
            message: 'Verification already validated',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    VerificationFileDownloaderHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091038',
            errorSearch: 'Access_Denied',
            message: 'Bad token access denied',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091039',
            errorSearch: 'Clear_File',
            message: 'could not delete temporary file',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091040',
            errorSearch: 'Create_Zip',
            message: 'it was not possible to create the zip',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091041',
            errorSearch: 'Get_File_Key',
            message: 'Could not get file from s3',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091042',
            errorSearch: 'Empty_Zip',
            message: 'There are no files related to the client',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    CrmClientFunction: [
        {
            statusCode: 500,
            errorCode: 'EL5001001',
            errorSearch: 'test error',
            message: 'This error is a test, managed by common layer',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    VerificationDataClientFunction: [
        {
            statusCode: 404,
            errorCode: 'ED4041004',
            errorSearch: 'Function_Does_Not_Exist',
            message: "Function doesn't exist",
            level: Constants_1.WARNING_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001001',
            errorSearch: 'Create_Verification_Error',
            message: 'Error creating verification process',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001002',
            errorSearch: 'Update_Verification_Error',
            message: 'Error updating specific verification',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001003',
            errorSearch: 'Update_ExtractedInfo_Error',
            message: 'Error updating extracted info verification',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001004',
            errorSearch: 'Update_Documents_Error',
            message: 'Error updating documents verification',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001005',
            errorSearch: 'Get_Verification',
            message: 'Error getting verification',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001006',
            errorSearch: 'Get_Lead_Verification',
            message: 'Error getting lead verification',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001007',
            errorSearch: 'Get_User_Verification',
            message: 'Error getting User verification',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    IdentityProviderDataFunction: [
        {
            statusCode: 424,
            errorCode: 'ED4241001',
            errorSearch: 'Dynamic_Error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    VerificationHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091043',
            errorSearch: 'Verification_Exist',
            message: 'Verification already exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001003',
            errorSearch: 'Missing_Body',
            message: 'Body must be present',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091054',
            errorSearch: 'simulation_not_exists',
            message: 'Simulation not exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091055',
            errorSearch: 'exceeded_maximum_age_term',
            message: 'The sum of age and term exceed the maximum age for the credit',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    NewSignatureHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091021',
            errorSearch: 'SIGNATURE_HAVE_PROCESS',
            message: 'A signature process already exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091022',
            errorSearch: 'SIGNATURE_NOT_CREATE',
            message: 'The signing process could not be created',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificSignatureHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091023',
            errorSearch: 'SIGNATURE_NOT_HAVE_PROCESS',
            message: 'No process found',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    StatusSignatureHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091048',
            errorSearch: 'SIGNATURE_NOT_HAVE_PROCESS',
            message: 'No process found',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificVerificationHandler: [
        {
            statusCode: 404,
            errorCode: 'EL4041001',
            errorSearch: 'Verification_Not_Exist',
            message: 'Verification not exists',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    UpdateExtractedInfoVerificationHandler: [
        {
            statusCode: 404,
            errorCode: 'EL4041002',
            errorSearch: 'Verification_Not_Exist',
            message: 'Verification not exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001004',
            errorSearch: 'Missing_Body',
            message: 'Body must be present',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'EL5001002',
            errorSearch: 'ED5001003',
            message: 'Internal Data Client Error',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091052',
            errorSearch: 'simulation_not_exists',
            message: 'Simulation not exists',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091053',
            errorSearch: 'exceeded_maximum_age_term',
            message: 'The sum of age and term exceed the maximum age for the credit',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    VerificationIDsGeneratorHandler: [
        {
            statusCode: 400,
            errorCode: 'EL4001008',
            errorSearch: 'invalid_id_type',
            message: 'Id type is not valid',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    CreditBureauDataServiceFunction: [
        {
            statusCode: 404,
            errorCode: 'ED4041005',
            errorSearch: 'Function_Does_Not_Exist',
            message: "Function doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041006',
            errorSearch: 'Contact_Does_Not_Exist',
            message: "Contact doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041007',
            errorSearch: 'Address_Does_Not_Exist',
            message: "Address doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041008',
            errorSearch: 'Country_Does_Not_Exist',
            message: "Country doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041009',
            errorSearch: 'Household_Does_Not_Exist',
            message: "Household doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'ED4001007',
            errorSearch: 'Credit_Bureau_Error',
            message: 'Credit bureau response error',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041010',
            errorSearch: 'Profile_Does_Not_Exist',
            message: "Profile doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041011',
            errorSearch: 'CreditType_Does_Not_Exist',
            message: "Credit Type doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041012',
            errorSearch: 'Product_Does_Not_Exist',
            message: "Product doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041013',
            errorSearch: 'Participant_Does_Not_Exist',
            message: "Participant doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041014',
            errorSearch: 'PaymentPeriod_Does_Not_Exist',
            message: "Payment Period doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 502,
            errorCode: 'ED5021001',
            errorSearch: 'Bureau_Error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 502,
            errorCode: 'ED5021002',
            errorSearch: 'Preoffer_Error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    ExecuteCBAnalysisHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091044',
            errorSearch: 'incorrect_otp',
            message: 'Provided code is not correct',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4041003',
            errorSearch: 'User_Data_Does_Not_Exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4041004',
            errorSearch: 'Credit_Analysis_Does_Not_Exists',
            message: 'Credit Analysis does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4041005',
            errorSearch: 'Verification_Data_Does_Not_Exists',
            message: 'User verification does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001005',
            errorSearch: 'Credit_Process_Request_Error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 502,
            errorCode: 'EL5021002',
            errorSearch: 'Bureau_Error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4041006',
            errorSearch: 'Signature_Data_Does_Not_Exists',
            message: 'Signature does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001006',
            errorSearch: 'Signature_Not_Completed',
            message: 'Signature status is not Complete',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificCreditAnalysisHandler: [
        {
            statusCode: 404,
            errorCode: 'EL4041007',
            errorSearch: 'Credit_Analysis_Does_Not_Exists',
            message: 'Credit Analysis does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    NewCreditAnalysisHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091045',
            errorSearch: 'Credit_Analysis_Already_Exists',
            message: 'Credit Analysis already exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificPreofferHanlder: [
        {
            statusCode: 409,
            errorCode: 'EL4091046',
            errorSearch: 'offer_not_exists',
            message: 'Offer does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    PreofferHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091008',
            errorSearch: 'simulation_not_exists',
            message: 'Simulation process does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091009',
            errorSearch: 'credit_analysis_not_exists',
            message: 'Credit analysis does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091010',
            errorSearch: 'virtual_appraisal_analysis_not_exists',
            message: 'Virtual appraisal analysis does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091011',
            errorSearch: 'credit_bureau_analysis_not_exists',
            message: 'Credit bureau analysis does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091003',
            errorSearch: 'not_viable_offer',
            message: 'User is not suited to get an offer',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091004',
            errorSearch: 'user_not_exists',
            message: 'User does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 502,
            errorCode: 'EL5021001',
            errorSearch: 'offer_dynamic_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091001',
            errorSearch: 'verification_fraud_attempt',
            message: 'Verification document: fraud attempt detected',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091002',
            errorSearch: 'credit_bureau_low_score',
            message: 'Credit bureau score is under 500',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091007',
            errorSearch: 'credit_bureau_rejection',
            message: 'User has rejection reasons',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091013',
            errorSearch: 'credit_bureau_review',
            message: 'User has review reasons',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091014',
            errorSearch: 'credit_bureau_no_hit',
            message: 'User has review reasons (no hit)',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091005',
            errorSearch: 'offer_process_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091006',
            errorSearch: 'offer_not_exists',
            message: 'Offer does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091012',
            errorSearch: 'verification_not_exists',
            message: 'Could not get user RFC from Identity Verification process',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AppraisalDataServiceFunction: [
        {
            statusCode: 404,
            errorCode: 'ED4041015',
            errorSearch: 'Function_Does_Not_Exist',
            message: "Function doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001008',
            errorSearch: 'Get_Appraisal_Error',
            message: 'Error getting appraisal',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001009',
            errorSearch: 'Create_Appraisal_Error',
            message: 'Error creating appraisal process',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificAppraisalHandler: [
        {
            statusCode: 404,
            errorCode: 'EL4041008',
            errorSearch: 'Appraisal_Analysis_Does_Not_Exists',
            message: "Appraisal analysis doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'EL5001003',
            errorSearch: 'ED5001008',
            message: 'Internal Data Client Error',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    NewAppraisalHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4091047',
            errorSearch: 'Appraisal_Analysis_Already_Exist',
            message: 'Appraisal analysis already exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'EL5001004',
            errorSearch: 'ED5001009',
            message: 'Internal Data Client Error',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 503,
            errorCode: 'EL5031001',
            errorSearch: 'appraisal_provider_dynamic_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AppraisalProviderServiceFunction: [
        {
            statusCode: 503,
            errorCode: 'EL5031002',
            errorSearch: 'appraisal_provider_dynamic_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'EL5001005',
            errorSearch: 'ED500100x',
            message: 'Internal Provider Data Client Error',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SimulationHandlerV3: [],
    LeadCreationHandlerV3: [],
    SignatureDataServiceFunction: [
        {
            statusCode: 404,
            errorCode: 'ED4041001',
            errorSearch: 'function_not_exist',
            message: "Function doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001010',
            errorSearch: 'create_signature_error',
            message: 'Error creating signature process',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001011',
            errorSearch: 'get_signature_error',
            message: 'Error getting signature process',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 500,
            errorCode: 'ED5001012',
            errorSearch: 'update_signature_error',
            message: 'Error updating signature process',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SignatureProviderDataServiceFunction: [
        {
            statusCode: 404,
            errorCode: 'ED4041002',
            errorSearch: 'function_not_exist',
            message: "Function doesn't exist",
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 502,
            errorCode: 'ED5021003',
            errorSearch: 'Signature_Error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    CompanyHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4095040',
            errorSearch: 'company_already_exists',
            message: 'A Company with the given RFC already exists',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SpecificCompanyHandler: [
        {
            statusCode: 404,
            errorCode: 'EL4045041',
            errorSearch: 'company_not_exists',
            message: 'Company does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    CompanyVerificationHandler: [
        {
            statusCode: 409,
            errorCode: 'EL4095042',
            errorSearch: 'company_already_verified',
            message: 'This company has been already verified',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4045041',
            errorSearch: 'company_not_exists',
            message: 'Company does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    SatwsWebhookHandler: [
        {
            statusCode: 503,
            errorCode: 'EL5035043',
            errorSearch: 'REQUEST_SATWS_FAILED',
            message: 'Request SATWS provider Failed',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4045044',
            errorSearch: 'Tax_Status_Not_Exists',
            message: 'Company Status Not found, generate extraction tax status'
        }
    ],
    TaxInformationDataService: [
        {
            statusCode: 503,
            errorCode: 'ED5035040',
            errorSearch: 'Sat_Request_Failed',
            message: 'Request SAT provider failed',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'ED4095041',
            errorSearch: 'company_dynamic_error',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    CUVUpdateHandler: [
        {
            statusCode: 400,
            errorCode: 'ED4001002',
            errorSearch: 'saf_query_error',
            message: 'Error en la consulta. Por favor revisa que el nombre de proyecto coincida con el registrado',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'ED4001003',
            errorSearch: 'project_name_error',
            message: 'Error en la consulta. Por favor revisa que el nombre de proyecto coincida con los datos del documento',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    InteliDataService: [
        {
            statusCode: 400,
            errorCode: 'ED4001004',
            errorSearch: 'intelli_user_error',
            message: 'User exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'ED4001005',
            errorSearch: 'Aplication_Request_Failed',
            message: 'Payload aplication failed',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    PdfFunction: [
        {
            statusCode: 400,
            errorCode: 'ED4001006',
            errorSearch: 'Template_Does_Not_Exist',
            message: 'Template does not exist',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    ApplicationCompletionHandler: [{
            statusCode: 409,
            errorCode: 'EL4091049',
            errorSearch: 'credit_already_process',
            message: 'El crédito ya fué procesado.',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091050',
            errorSearch: 'error_persons_register',
            message: 'No se pudo registrar a los participantes, es posible que ya se encuentren registrados.',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091050',
            errorSearch: 'error_credit_register',
            message: 'No se pudo registrar el crédito.',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 409,
            errorCode: 'EL4091051',
            errorSearch: 'error_result_ori_engine',
            message: '',
            level: Constants_1.ERROR_LEVEL
        }],
    AppionQueryHandler: [],
    LogbookSearchHandler: [
        {
            statusCode: 400,
            errorCode: 'ED4001007',
            errorSearch: 'search_type_invalid',
            message: 'Available type values: nuc, client_name, project_name'
        },
        {
            statusCode: 500,
            errorCode: 'ED500004',
            errorSearch: 'logbook_data_service_error',
            message: 'Logbook data service failed'
        }
    ],
    UpdateLogbookHandler: [
        {
            statusCode: 404,
            errorCode: 'ED4041003',
            errorSearch: 'logbook_data_not_found',
            message: 'Logbook does not exists'
        },
        {
            statusCode: 500,
            errorCode: 'ED500005',
            errorSearch: 'update_logbook_error',
            message: 'Fail trying update logbook in database'
        },
        {
            statusCode: 500,
            errorCode: 'ED500006',
            errorSearch: 'put_comments_logbook_error',
            message: 'Fail trying save comments in database'
        }
    ],
    ReportLogbookHandler: [
        {
            statusCode: 404,
            errorCode: 'ED4041016',
            errorSearch: 'logbook_data_not_found',
            message: 'Logbook does not exists'
        },
        {
            statusCode: 500,
            errorCode: 'ED500007',
            errorSearch: 'pdf_empty_response',
            message: 'Cannot generate PDF logbook'
        }
    ],
    LogbookDataServiceFunction: [
        {
            statusCode: 500,
            errorCode: 'ED500008',
            errorSearch: 'Get_Logbook_By_Id_Error',
            message: 'Error at getting logbook data by id from dynamo'
        },
        {
            statusCode: 500,
            errorCode: 'ED500009',
            errorSearch: 'Get_Logbook_Error',
            message: 'Error at getting logbook data by nuc from dynamo'
        },
        {
            statusCode: 500,
            errorCode: 'ED500010',
            errorSearch: 'Get_Logbook_List_Error',
            message: 'Error at getting list logbook data'
        },
        {
            statusCode: 500,
            errorCode: 'ED500011',
            errorSearch: 'Create_Logbook_Error',
            message: 'Error at logbook create'
        },
        {
            statusCode: 500,
            errorCode: 'ED500012',
            errorSearch: 'Update_Logbook_Error',
            message: 'Error at logbook update'
        },
        {
            statusCode: 500,
            errorCode: 'ED500013',
            errorSearch: 'Add_Commets_Logbook_Error',
            message: 'Error at logbook add comments'
        }
    ],
    SAFDataService: [
        {
            statusCode: 500,
            errorCode: 'ED500014',
            errorSearch: 'Saf_Query_Error',
            message: 'Error at execute query to saf'
        }
    ],
    OrchestratorFunction: [
        {
            statusCode: 404,
            errorCode: 'ED4041017',
            errorSearch: 'arango_buro_empty_response',
            message: 'Arango buro data not found'
        },
        {
            statusCode: 500,
            errorCode: 'ED500015',
            errorSearch: 'error_sending_email',
            message: 'Something failed sending the email notification'
        }
    ],
    IntelliDataSenderFunction: [
        {
            statusCode: 500,
            errorCode: 'ED500016',
            errorSearch: 'register_user_error',
            message: 'Error trying to register user to intelli'
        },
        {
            statusCode: 500,
            errorCode: 'ED500017',
            errorSearch: 'application_start_error',
            message: 'Error trying to start application to intelli '
        },
        {
            statusCode: 500,
            errorCode: 'ED500018',
            errorSearch: 'update_token_user_error',
            message: 'Error at update intelli token in user table'
        }
    ],
    ConstructionProgressHandler: [
        {
            statusCode: 404,
            errorCode: 'EL4041010',
            errorSearch: 'Construction_Progress_Structure_Not_Found',
            message: 'Construction progress structure not found with the provided credit number',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'EL4041009',
            errorSearch: 'Bridge_Loan_Not_Found',
            message: 'Bridge loan not found with provided credit number',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'EL4001007',
            errorSearch: 'Bad_Request_Body_Error',
            message: 'Request Body Structure is wrong or missing some attribute',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    ObtainOnsiteAppraisalHandler: [
        {
            statusCode: 404,
            errorCode: 'ED4041311',
            errorSearch: 'onsite_appraisal_not_found',
            message: 'Appraisal Valuation not found, please create first an appraisal valuation',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    ObtainAppraisalPricingHandler: [
        {
            statusCode: 400,
            errorCode: 'ED4001312',
            errorSearch: 'home_value_not_present',
            message: 'Home value not present in request',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 404,
            errorCode: 'ED4041314',
            errorSearch: 'could_not_get_appraisal_pricing',
            message: 'Could not get appraisal pricing',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    OnsiteAppraisalPaymentHandler: [
        {
            statusCode: 400,
            errorCode: 'EL4001310',
            errorSearch: 'user-id_not_present',
            message: 'User id not present in request, please add',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'ED4001312',
            errorSearch: 'home_value_not_present',
            message: 'Home value not present in request',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'ED4001313',
            errorSearch: 'appraiser_id_not_present',
            message: 'Appraiser id not present in request',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 400,
            errorCode: 'ED4001315',
            errorSearch: 'process_onsite_appraisal_exists',
            message: 'The user already has a valuation process',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AccountStatementsHandler: [
        {
            statusCode: 400,
            errorCode: 'EL4041011',
            errorSearch: 'Account_Statement_Not_Found',
            message: 'Account statement not found',
            level: Constants_1.ERROR_LEVEL
        }
    ],
    AppointmentHandler: [
        {
            statusCode: 501,
            errorCode: 'EL5010010',
            errorSearch: 'user_id_required',
            message: 'user id is required',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 501,
            errorCode: 'EL5010011',
            errorSearch: 'user_data_not_exists',
            message: 'user does not exist',
            level: Constants_1.ERROR_LEVEL
        },
        {
            statusCode: 501,
            errorCode: 'EL5010012',
            errorSearch: 'study_already_exists',
            message: 'study already exists ',
            level: Constants_1.ERROR_LEVEL
        }
    ]
};
//# sourceMappingURL=ErrorCodes.js.map