"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChronosLambdaClientService = void 0;
const client_lambda_1 = require("@aws-sdk/client-lambda");
const Enums_1 = require("../models/Enums");
class ChronosLambdaClientService {
    /**
     *
     * @param LAMBDA_NAME is AWS Lambda Name to be invoked
     * @param ENVIRONMENT is ENVIRONMENT env var
     * @param LAMBDA_LOCAL_ENDPOINT is Lambda Local Endpoint
     * @param AWS_REGION is AWS region
     */
    constructor(LAMBDA_NAME, ENVIRONMENT, LAMBDA_LOCAL_ENDPOINT, AWS_REGION) {
        this.LAMBDA_NAME = LAMBDA_NAME;
        this.ENVIRONMENT = ENVIRONMENT;
        this.LAMBDA_LOCAL_ENDPOINT = LAMBDA_LOCAL_ENDPOINT;
        this.AWS_REGION = AWS_REGION;
        this.options = {
            region: this.AWS_REGION
        };
        if (this.ENVIRONMENT === Enums_1.EnvironmentEnum.LOCAL_STAGE) {
            this.options.endpoint = this.LAMBDA_LOCAL_ENDPOINT;
        }
        this.awsLambdaClient = new client_lambda_1.LambdaClient(this.options);
    }
    /**
     *
     * @param payload is Chronos lambda-to-lambda request body
     * @param loggerInstance is chronos logger instance
     * @param invocationType is AWS Lambda invocationType ("Event" | "RequestResponse" | "DryRun")
     * @returns object with execution response
     */
    async invokeChronosLambda(payload, loggerInstance, invocationType = Enums_1.LambdaInvocationTypeEnum.REQUEST_RESPONSE) {
        const params = new client_lambda_1.InvokeCommand({
            FunctionName: this.LAMBDA_NAME,
            InvocationType: invocationType,
            LogType: 'Tail',
            Payload: JSON.stringify(Object.assign(Object.assign({}, payload), { env: this.ENVIRONMENT }))
        });
        loggerInstance.info(`Calling lambda ${this.LAMBDA_NAME}`, {
            lambdaName: this.LAMBDA_NAME,
            lambdaPayload: payload
        });
        const lambdaResult = await this.awsLambdaClient.send(params);
        let response = {};
        if (invocationType === Enums_1.LambdaInvocationTypeEnum.REQUEST_RESPONSE) {
            const result = Buffer.from(lambdaResult.Payload).toString('utf-8');
            const parsed = JSON.parse(result);
            //Lambda invocation
            if (lambdaResult.StatusCode !== 200)
                throw new Error(lambdaResult.FunctionError);
            //Computation result
            if (parsed.statusCode !== 200)
                throw new Error(parsed.body);
            response = JSON.parse(parsed.body);
        }
        return response;
    }
}
exports.ChronosLambdaClientService = ChronosLambdaClientService;
//# sourceMappingURL=ChronosLambdaClientService.js.map