"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorHandlerService = void 0;
const ErrorCodes_1 = require("../models/ErrorCodes");
const Constants_1 = require("../models/Constants");
class ErrorHandlerService {
    handleError(request) {
        console.error(request.error);
        return this.searchError(request.context.functionName, request.error.message, request.event, request.error.stack);
    }
    searchError(lambda, errorMessage, event, errorStack) {
        try {
            console.debug('> Error received in ErrorHandlerService');
            console.debug('Function name:', lambda);
            console.debug('Error message:', errorMessage);
            console.debug('Error stack:', errorStack);
            console.debug('Original event:', event);
            let errorFound = ErrorCodes_1.ErrorCodes.GenericErrors.find((errorCode) => errorMessage.includes(errorCode.errorSearch));
            if (!errorFound) {
                errorFound = ErrorCodes_1.ErrorCodes[lambda].find((errorCode) => errorMessage.includes(errorCode.errorSearch));
            }
            let finalMessageError = errorMessage.includes('Dynamic_Error') ? errorMessage.replace('Dynamic_Error', '') : errorFound.message;
            finalMessageError = finalMessageError.includes(errorFound === null || errorFound === void 0 ? void 0 : errorFound.errorSearch) ? finalMessageError.replace(errorFound === null || errorFound === void 0 ? void 0 : errorFound.errorSearch, '') : finalMessageError;
            console.debug('errorFound', errorFound);
            if (lambda.includes(Constants_1.API_HANDLER)) {
                return this.formatApiError(errorFound.statusCode, errorFound.errorCode, errorFound.level, finalMessageError);
            }
            else {
                return this.formatLambdaError(errorFound.statusCode, errorFound.errorCode, finalMessageError);
            }
        }
        catch (error) {
            const UNEXPECTED_ERROR = 'Unexpected error on ' + lambda + ':' + errorMessage.replace('Dynamic_Error', '');
            console.error(UNEXPECTED_ERROR);
            if (lambda.includes(Constants_1.API_HANDLER)) {
                return this.formatApiError(500, Constants_1.UNEXPECTED_ERROR_CODE, Constants_1.ERROR_LEVEL, UNEXPECTED_ERROR);
            }
            return this.formatLambdaError(500, Constants_1.UNEXPECTED_ERROR_CODE, UNEXPECTED_ERROR);
        }
    }
    formatApiError(statusCode, code, level, error) {
        return {
            statusCode: statusCode,
            headers: {
                'Access-Control-Allow-Headers': 'Content-Type',
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Methods': '*'
            },
            body: JSON.stringify({
                data: {},
                notification: {
                    code: code,
                    level: level,
                    message: error,
                    timestamp: new Date()
                }
            })
        };
    }
    formatLambdaError(statusCode, code, error) {
        return {
            statusCode: statusCode,
            body: JSON.stringify({
                code: code,
                message: error
            })
        };
    }
}
exports.ErrorHandlerService = ErrorHandlerService;
//# sourceMappingURL=ErrorHandlerService.js.map